Crate qubit

Crate qubit 

Structs

Codegen
Code generation for Qubit. Collects all required information to pass to a Backend implementation.
Extensions
A type map of protocol extensions.
HandlerCodegen
Representation of a handler function, for the purpose of code generation.
Router
Qubit router, which will contain all handlers.
RpcError
An RPC error response. See documentation. for addtional information.
TypeScript
TypeScript implementation of Qubit type generation.

Enums

BackendStage
Available codegen backend stages.
ErrorCode
JSONRPC error code

Traits

Backend
Code generation backend implementation.
FromRequestExtensions
Context can be built from request information by implementing the following trait. The extensions are passed in from the request (see Extensions), which can be added using tower middleware.
HandlerBackend
Backend implementation for handlers.
QubitHandler
A handler suitable for use with Qubit.
RegisterableHandler
Registration implementation differs depending on the return type of the handler. This is to account for handlers which may return futures, streams, or values directly.
TypeBackend
Backend implementation for handlers.

Attribute Macros

handler
See [qubit::builder::handler] for more information.
ts
Mark a type to be exported to TypeScript.